<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id_ID">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Hapus bingkai jendela</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Balik vertikal</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Balik horizontal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Membalikkan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu-abu</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-Putih</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Beralih ke Jendela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Beralih ke Layar Penuh</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Penyiapan berhasil.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Tutup jendela ini dan jalankan vokoscreenNG lagi.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Bersenang-senanglah dengan vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Percakapan</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tidak ada pengelola file yang ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Silakan instal pengelola file.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tidak ada pengelola file yang ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Silakan instal pengelola file.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Perekaman tidak dimulai, ruang disk kosong tidak cukup.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Batas ruang disk kosong tercapai.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Batas ruang disk kosong</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabita</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Perekaman dihentikan, ruang disk kosong tidak cukup.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Tidak ada pengelola file yang ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Silakan instal pengelola file.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kode sumber</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Beranda</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Terjemahan</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Kode sumber</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Beranda</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Terjemahan</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Tidak ada pengelola file yang ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Silakan instal pengelola file.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tidak ada pengelola file yang ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Silakan instal pengelola file.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjutkan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjutkan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Percakapan</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Balik horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Balik vertikal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Membalikkan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu-abu</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-Putih</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Hapus bingkai jendela</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Pengaturan Kamera</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Atur Ulang</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Hitung Mundur</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Ukuran video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ruang disk kosong:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasi</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Waktu rekam:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Suara</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Bingkai</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>VideoCodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>AudioCodec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Jangan rekam kursor mouse</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Jam</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Menit</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Mulai Timer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Berhenti merekam setelah</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Jam</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Menit</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Detik</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Batas ruang disk kosong</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tampilkan di systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Tunggu kedua sebelum merekam</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Cari pembaruan</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tersedia</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Tidak Tersedia</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjutkan</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Mainkan</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Membalikkan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu-abu</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Putar rekaman terakhir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalkan jendela saat perekaman dimulai</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Mulai minimalkan jendela</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Balik horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Balik vertikal</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-Putih</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Hapus bingkai jendela</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Setel ulang semua pengaturan di awal berikutnya</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Hak cipta dan lisensi dari gambar</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabita</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Siaran layar</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Pemain</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Catatan</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Secara otomatis</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Buat gambar tab</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informasi lisensi</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>NYALA</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>MATI</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Pintasan keyboard global</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Tombol pintasan yang ditetapkan.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Pintasan keyboard tidak ditetapkan atau ditetapkan lebih dari satu kali.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Jika ditampilkan ditugaskan tetapi tidak berfungsi, itu sedang digunakan oleh program lain.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Fotopath</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Sembunyikan jendela ini</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Beberapa detik menunggu sebelum merekam</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Hak cipta dan lisensi dari gambar</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Buat gambar tab</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informasi lisensi</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>NYALA</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>MATI</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Waktu rekam:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Ukuran video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ruang disk kosong:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasi</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>VideoCodec</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Bingkai</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tersedia</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Tidak Tersedia</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Jangan rekam kursor mouse</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>AudioCodec</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Hitung Mundur</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Membalikkan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu-abu</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-Putih</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Balik vertikal</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Balik horizontal</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Hapus bingkai jendela</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Tunggu kedua sebelum merekam</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Atur Ulang</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Sembunyikan jendela ini</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Beberapa detik menunggu sebelum merekam</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Hak cipta dan lisensi dari gambar</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Mainkan</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
</context>
</TS>